import setuptools

setuptools.setup(
    name="Demographics_box",
    version="1.1",
    author="Emmanuel Sevrin",
    description="A package to generate list of people",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)